/**
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.deephacks.tools4j.config.admin;

import java.util.List;

import org.deephacks.tools4j.config.model.Bean;
import org.deephacks.tools4j.config.model.Bean.BeanId;
import org.deephacks.tools4j.config.spi.Conversion.Converter;

public class BeanToWsBeanConverter implements Converter<Bean, WsBean> {

    @Override
    public WsBean convert(Bean bean, Class<? extends WsBean> specificType) {
        WsBean wsBean = new WsBean();
        wsBean.setInstanceId(bean.getId().getInstanceId());
        wsBean.setSchemaName(bean.getId().getSchemaName());
        for (String name : bean.getReferenceNames()) {
            List<BeanId> ids = bean.getReference(name);
            for (BeanId id : ids) {
                WsReference ref = new WsReference();
                ref.setInstanceId(id.getInstanceId());
                ref.setSchemaName(id.getSchemaName());
                ref.setName(name);
                if (wsBean.getReferences() == null) {
                    wsBean.setReferences(new References());
                }
                wsBean.getReferences().getReferences().add(ref);
            }
        }
        for (String name : bean.getPropertyNames()) {
            List<String> values = bean.getValues(name);
            for (String value : values) {
                WsProperty property = new WsProperty();
                property.setName(name);
                property.setValue(value);
                if (wsBean.getProperties() == null) {
                    wsBean.setProperties(new Properties());
                }
                wsBean.getProperties().getProperties().add(property);
            }
        }
        return wsBean;
    }
}
