/**
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.deephacks.tools4j.config.admin;

import org.deephacks.tools4j.config.model.Bean;
import org.deephacks.tools4j.config.model.Bean.BeanId;
import org.deephacks.tools4j.config.spi.Conversion.Converter;

public class WsBeanToBeanConverter implements Converter<WsBean, Bean> {

    @Override
    public Bean convert(WsBean wsbean, Class<? extends Bean> specificType) {

        Bean bean = Bean.create(BeanId.create(wsbean.getInstanceId(), wsbean.getSchemaName()));
        Properties properties = wsbean.getProperties();
        if (properties != null) {
            for (WsProperty property : properties.getProperties()) {
                bean.addProperty(property.getName(), property.getValue());
            }
        }
        References references = wsbean.getReferences();
        if (references != null) {
            for (WsReference reference : references.getReferences()) {
                BeanId ref = BeanId.create(reference.getInstanceId(), reference.getSchemaName());
                bean.addReference(reference.getName(), ref);
            }

        }

        return bean;
    }
}
